==> optimap-0.3.0.tar.gz: optimap-0.3.0/README.md <==
# optimap

[![docs](https://github.com/cardiacvision/optimap/actions/workflows/docs.yml/badge.svg)](https://cardiacvision.github.io/optimap/)
[![tests](https://github.com/cardiacvision/optimap/actions/workflows/main.yml/badge.svg)](https://github.com/cardiacvision/optimap/actions/workflows/main.yml)
[![PyPI](https://img.shields.io/pypi/v/optimap.svg)](https://pypi.org/project/optimap/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/optimap.svg)](https://python.org)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.8336455.svg)](https://doi.org/10.5281/zenodo.13922150)

### optimap: An open-source library for processing fluorescence video data

`optimap` is an open-source Python toolbox for exploring, visualizing, and analyzing high-speed fluorescence imaging data with a focus on cardiac optical mapping data. It includes modules for loading, processing and exporting videos, extracting and measuring optical traces, visualizing action potential or calcium waves, tracking motion and compensating motion artifacts, computing activation maps, conduction velocities, action potential durations, as well as measuring contractility and further analyzing and visualizing the results. Refer to the [Tutorials](https://cardiacvision.github.io/optimap/main/tutorials/) and the [Documentation](https://cardiacvision.github.io/optimap/) for more information about optimap's features.

## Installation

`optimap` is available for macOS, Windows and Linux, see the [Getting Started](https://cardiacvision.github.io/optimap/main/chapters/getting_started/) guide for more information.

You can install `optimap` using [pip](https://packaging.python.org/en/latest/tutorials/installing-packages/):

```bash
pip install optimap
```

To update optimap to the latest version run

```bash
pip install --upgrade optimap
```

## About optimap

`optimap` is an interactive, script or notebook-based software library created for cardiovascular scientists in particular, but might also be useful for scientists in other fields. For instance, when performing calcium imaging or physiological research with moving cells or tissues. It is designed to be a flexible and customizable analysis workflow toolkit, which allows for a wide range of analyses and visualizations. See the [Tutorials](https://cardiacvision.github.io/optimap/main/tutorials/) for examples and more information about the usage of `optimap`. The tutorials can be downloaded by clicking on the link in the green box at the top of each tutorial page.

`optimap` is developed by Jan Lebert and Jan Christoph of the [Cardiac Vision Laboratory](https://cardiacvision.ucsf.edu) at the [University of California, San Franicsco](https://www.ucsf.edu). It is open-source, freely available, and relies on open-source packages such as NumPy, SciPy, Matplotlib and OpenCV.

## Links

- [Documentation](https://cardiacvision.github.io/optimap/)
- [Issue tracker](https://github.com/cardiacvision/optimap/issues)
- [Source code](https://github.com/cardiacvision/optimap)

## Contributing

We welcome bug reports, questions, ideas for new features and pull-requests to fix issues or add new features to optimap. See [Contributing](https://cardiacvision.github.io/optimap/main/chapters/contributing/) for more information.

## License

optimap is licensed under the [MIT License](https://github.com/cardiacvision/optimap/blob/main/LICENSE.md).

==> optimap-0.3.1.tar.gz: optimap-0.3.1/README.md <==
# optimap

[![docs](https://github.com/cardiacvision/optimap/actions/workflows/docs.yml/badge.svg)](https://cardiacvision.github.io/optimap/)
[![tests](https://github.com/cardiacvision/optimap/actions/workflows/main.yml/badge.svg)](https://github.com/cardiacvision/optimap/actions/workflows/main.yml)
[![PyPI](https://img.shields.io/pypi/v/optimap.svg)](https://pypi.org/project/optimap/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/optimap.svg)](https://python.org)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.8336455.svg)](https://doi.org/10.5281/zenodo.13922150)

### optimap: An open-source library for processing fluorescence video data

`optimap` is an open-source Python toolbox for exploring, visualizing, and analyzing high-speed fluorescence imaging data with a focus on cardiac optical mapping data. It includes modules for loading, processing and exporting videos, extracting and measuring optical traces, visualizing action potential or calcium waves, tracking motion and compensating motion artifacts, computing activation maps, conduction velocities, action potential durations, as well as measuring contractility and further analyzing and visualizing the results. Refer to the [Tutorials](https://cardiacvision.github.io/optimap/main/tutorials/) and the [Documentation](https://cardiacvision.github.io/optimap/) for more information about optimap's features.

## Installation

`optimap` supports macOS, Windows, and Linux. See the [Getting Started](https://cardiacvision.github.io/optimap/main/chapters/getting_started/) guide for more information.

You can install `optimap` using [pip](https://packaging.python.org/en/latest/tutorials/installing-packages/):

```bash
pip install optimap
```

To update optimap to the latest version run

```bash
pip install --upgrade optimap
```

## About optimap

`optimap` is an interactive, script or notebook-based software library created for cardiovascular scientists in particular, but might also be useful for scientists in other fields. For instance, when performing calcium imaging or physiological research with moving cells or tissues. It is designed to be a flexible and customizable analysis workflow toolkit, which allows for a wide range of analyses and visualizations. See the [Tutorials](https://cardiacvision.github.io/optimap/main/tutorials/) for examples and more information about the usage of `optimap`. The tutorials can be downloaded by clicking on the link in the green box at the top of each tutorial page.

`optimap` is developed by Jan Lebert and Jan Christoph of the [Cardiac Vision Laboratory](https://cardiacvision.ucsf.edu) at the [University of California, San Franicsco](https://www.ucsf.edu). It is open-source, freely available, and relies on open-source packages such as NumPy, SciPy, Matplotlib and OpenCV.

## Links

- [Documentation](https://cardiacvision.github.io/optimap/)
- [Issue tracker](https://github.com/cardiacvision/optimap/issues)
- [Source code](https://github.com/cardiacvision/optimap)

## Contributing

We welcome bug reports, questions, ideas for new features and pull-requests to fix issues or add new features to optimap. See [Contributing](https://cardiacvision.github.io/optimap/main/chapters/contributing/) for more information.

## License

optimap is licensed under the [MIT License](https://github.com/cardiacvision/optimap/blob/main/LICENSE.md).
